==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/ArrowsUpDownLeftRight.md <==
# ArrowsUpDownLeftRight


```text
fontawesome-6/Solid/ArrowsUpDownLeftRight
```

```text
include('fontawesome-6/Solid/ArrowsUpDownLeftRight')
```



| Illustration | ArrowsUpDownLeftRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/ArrowsUpDownLeftRight.png) | ![illustration for ArrowsUpDownLeftRight](../../fontawesome-6/Solid/ArrowsUpDownLeftRight.Local.png) |




## ArrowsUpDownLeftRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowsUpDownLeftRight
include('fontawesome-6/Solid/ArrowsUpDownLeftRight')

' renders the element
ArrowsUpDownLeftRight('ArrowsUpDownLeftRight', 'Arrows Up Down Left Right', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowsUpDownLeftRight
include('fontawesome-6/Solid/ArrowsUpDownLeftRight')

' renders the element
ArrowsUpDownLeftRight('ArrowsUpDownLeftRight', 'Arrows Up Down Left Right', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/ArrowsUpDownLeftRight.md <==
# ArrowsUpDownLeftRight


```text
fontawesome-6/Solid/ArrowsUpDownLeftRight
```

```text
include('fontawesome-6/Solid/ArrowsUpDownLeftRight')
```



| Illustration | ArrowsUpDownLeftRight |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/ArrowsUpDownLeftRight.png) | ![illustration for ArrowsUpDownLeftRight](../../fontawesome-6/Solid/ArrowsUpDownLeftRight.Local.png) |




## ArrowsUpDownLeftRight

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowsUpDownLeftRight
include('fontawesome-6/Solid/ArrowsUpDownLeftRight')

' renders the element
ArrowsUpDownLeftRight('ArrowsUpDownLeftRight', 'Arrows Up Down Left Right', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element ArrowsUpDownLeftRight
include('fontawesome-6/Solid/ArrowsUpDownLeftRight')

' renders the element
ArrowsUpDownLeftRight('ArrowsUpDownLeftRight', 'Arrows Up Down Left Right', 'an optional tech label', 'an optional description')
@enduml
```
